@@ -18,6 +18,8 @@ def main():
 
     if 'basic' in yamlinfo and 'log' in yamlinfo['basic'] and yamlinfo['basic']['log']!=None:
         log = yamlinfo['basic']['log']
+        if os.path.exists(log):
+            os.remove(log)
         logger.add(log, level="TRACE", backtrace=True, diagnose=True)
 
     if yamlinfo['mod']=='img_upload':
